# Applying the Development/Evaluation Framework

In this section we seek to evaluate our new inference methods. This has the added benefit of allowing us to demonstrate the new evaluation framework.

## Models of Interest
* System generated models:
    * **VI**: HDP model with variational inference.
    * **GB**: HDP model with Gibb's sampler.
* Baselines (Upper/Lower)
    * **REF**: When possible (e.g. when using ROUGE measures) we include a measure of self-similarity among all gold-standards. This measurement of intra-gold agreement serves as a rough upper-bound on the performance of any system-generated timelines. 
    * **BL**: Baseline binary-classification model.

## Choosing Entities

Our entity set was created by first choosing an overarching domain, in our case US Politics. We then performed a manual boot-strap. We chose several key entities in the domain as seeds. In our case, these were Donald Trump, Hillary Clinton and Bernie Sanders. We then sampled articles from news linked to these entities. For each of these articles, we manually identified other relevant named entities. These other entities were used as the seeds for subsequent iterations. We repeated this process until we had a list of fourty entities, and we randomly sampled a 50:50 test/train split.

## Article Linking Methodology

For each entity, we found a corpus of articles through the Bing API; We queried on entity-name with source set to 'News' and topic to 'politics'. We then scraped the returned URLs to retrieve the article text. We should be able to handle noisy input, so we have made little effort in terms of data-validation and cleaning.

## Gold-standard Generation Methodology

We adopt a crowd-based approach to generating our gold-standards. Workers were given the Wikipedia page of the entity as reference. They were then tasked with finding a selection of news articles which best summarised the entity. Specifically, they were asked to ensure the union of the articles was relevant, informative and non-redundant. This task was repeated five times per entity with different workers.

## Automatic Metrics

### ROUGE

ROUGE is a popular family of metrics used for automatically evaluating summaries. A single ROUGE calculation takes as input all gold-standard models and one candidate model.  Intuitively, the higher the ROUGE scores, the more similar the candidate model is to the gold standard. See (**APPENDIX B**) for more information on how ROUGE is calculated and what it indicates.

ROUGE methods used:

* **R-1:** ROUGE-F based on unigrams.
* **R-2:** ROUGE-F based on bigrams.
* **R-W:** ROUGE-F based on longest common subsequence.

### Per-Word Log-Likelihood

This is a measure of the predictive power of the topic-model underlying our VI and GB implementations. Essentially we make a test/train split on our documents. For all test documents, we condition on 90% of the included words as well as our training data and calculate the probability of observing the remaining 10% of words. For numerical stability this is calculated in the log-domain. The final metric is simply the average across all test-documents. We have adopted this metric from Wang et al. For a full overview of how it is calculated, please see the reference paper\cite{Wang2011}.

## Crowd Evaluation Strategy

Our crowd-workers were given a timeline generated by each model of interest, as well as the Wikipedia page of the entity for reference. They were asked to perform two tasks. Firstly, they read all timelines and scored each independently over three domains -- relevancy, comprehensibility and conciseness. They were then asked to rank all timelines preferentially, where one was their most preferred timeline.