## Representing the TLG Problem

In general TLG is treated as a Bayesian inference task. As this is not the primary focus of this paper, we simply adopt the work of Ahmed et al. \cite{Ahmed2011}. This is a formulation of the problem in a non-parametric Bayesian context. Essentially, the corpus is processed by a topic model. We use this to cluster articles together into story-topics. We then take a  subset of these story-clusters and extract a representative sentence from each.

### Components


**Topic models**:

* Topics can be seen as a distribution over the words in the corpus. A document in turn is represented as a mixture of these topics. Incorporating a topic structure into our model gives us an intuitive and understandable document representation.
* Looking at the topic distribution also lets us prioritise certain kinds of sentences or stories.
* We use a form of temporally-dependent hierarchal dirichlet process (HDP). The specifics are not relevant to the results of this paper, but in essence it is a topic model with several desirable properties. Firstly, topics can change, grow or disappear as time passes and the data dictates. Secondly, the topics are hierarchal, generally represented as a tree-like structure

**Story-Level Clustering**: 

* Our model handles both current and historical articles. Several domains where the TLG model is desirable (e.g. news) are characterised by a large historical catalog and high frequency.
* As such our clustering model has to be scaleable and ideally functional in a streaming context.

**Summarisation**:

* While clustering and topic modeling are useful structuring tools, we must still compress the data for human readability.
* We have two options. We either select the most representative article from a given story and perform single-document sentence-selection. Alternatively, we can perform sentence selection on the whole story-cluster.

See **(Fig 2)**.